Module scsys_core::extract

source ·

Structs

  • Implements the formal interface for operating the extraction features
  • Extract the contents of a file

Traits

  • A complete interface for interacting with files and file-like objects