this module implements various traits supporting the Id type
Modules
Traits
- HashId
- Identifier
- An
Identifieris a type that can be used as an identifier - Identifier
Ext - Identify
- Identify
Mut - Identity
- The
Idtrait describes the behavior of a type that can be used as an id. AnIdis almost identical to anIdentifier, but it is a trait that can be implemented for any type. - RawIdentifier
- StdId