Module scsys_core::prelude
source · Re-exports
pub use super::applicative::Applicative;pub use super::functor::Functor;pub use super::monad::Monad;pub use super::HKT;pub use super::kv::Store as KeyValue;pub use super::OrInsert;pub use super::IntoInner;pub use super::Name;pub use super::direction::Direction;pub use super::BoxAny;pub use super::Result;pub use crate::errors::*;pub use crate::time::*;pub use super::appellation::*;pub use super::classify::*;
Structs
Enums
Traits
- The
Idtrait describes the behavior of a type that can be used as an id. AnIdis almost identical to anIdentifier, but it is a trait that can be implemented for any type. - An
Identifieris a type that can be used as an identifier
Functions
- A generic function wrapper extending glob::glob
- This function converts the file found at path (fp) into a Vec
- Remove the first and last charecters of a string
- Simple function wrapper evaluating the claim that the given information is of type f64
- Simple function wrapper evaluating the claim that the given information is of type f64
- Checks to see if the input is a string
- Fetch the project root unless specified otherwise with a CARGO_MANIFEST_DIR env variable
Type Aliases
- Type alias for async errors
- Type alias for async results
- Type alias for a boxed error with send, sync, and static flags enabled
- Type alias for the standard result used
- Type alias for std::io::Result
- Type alias wrapping a locked, thread-safe structure with a std::sync::Mutex in an std::sync::Arc