Function scsys_core::prelude::is_str_float
source · pub fn is_str_float<T: ToString>(data: &T) -> boolExpand description
Simple function wrapper evaluating the claim that the given information is of type f64
pub fn is_str_float<T: ToString>(data: &T) -> boolSimple function wrapper evaluating the claim that the given information is of type f64