this module implements a generic State wrapper and provides several traits to support
state management and other stateful workloads.
Modules
- nstate
- this module implements an alternative stateful representation that enables one to provide a data type as well as specify the state kind
- traits
- this module implements various traits supporting the
Statetype - types
- additional types for the
statemodule - wrapper
Structs
- Nary
- State
Stateis generic over some typeQthat implements theRawStatetrait.- State
Base StateBaseis an abstract object that allows a particular kind of state to be associated with some generic stateQ
Enums
Traits
- NState
Kind - a particular kind of state that is defined by some rank
- RawState
- RawState is a trait that defines the types of states
- RawState
Kind - a private, base represenation of a state kind
- State
Kind - note: this trait is auto implemented for types that implement
AsRef<str>. - State
Repr - The
StateReprtrait defines the base type for stateful items, allowing for a generic item type to be associated with the state. - Stateful
Statefulis a trait establishing a common interface for all types that are state-aware.
Type Aliases
- Binary
State - Denary
State - NState
- A type alias for a
StateBaseequipped with aNarykind of state - Nonary
State - Octonary
State - Quaternary
State - Quinary
State - Senary
State - Septenary
State - Ternary
State - Unary
State