Module time

a temporal module establishing a core set of time-related primitives and utilities such as Timestamp

Time

The time module provides a set of utilities for working with time and timestamps.

Modules

timestamp
this module implements the Timestamp type

Structs

Date
DateTime
Epoch
Time
Timestamp
Timestamp is a generic implementation of a type that represents some point in time.

Traits

Now
The Now trait provides a common creation routines for all datetime implementations.
RawTimestamp
a private trait used to mark types capable of being uses as a basetype for a [Timestamp].

Functions

std_time
systime is a utilitarian function that returns the current system time in milliseconds.
systime
systime is a utilitarian function that returns the current system time in milliseconds.